hipLibraryGetGlobal

Function hipLibraryGetGlobal 

pub unsafe extern "C" fn hipLibraryGetGlobal(
    dptr: *mut *mut c_void,
    bytes: *mut usize,
    library: hipLibrary_t,
    name: *const c_char,
) -> hipError_t
@brief Get device pointer to a __device__ global variable defined in a library.

Returns the device pointer and size of the named global symbol within the library’s code object. Mirrors CUDA’s cuLibraryGetGlobal / cudaLibraryGetGlobal. Either dptr or bytes (but not both) may be NULL.

@param [out] dptr Pointer to receive the device pointer, may be NULL. @param [out] bytes Pointer to receive the size in bytes, may be NULL. @param [in] library Input hip library handle. @param [in] name Name of the global symbol to look up. @return #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidResourceHandle, #hipErrorNotFound