hipMemDiscardBatchAsync

Function hipMemDiscardBatchAsync 

pub unsafe extern "C" fn hipMemDiscardBatchAsync(
    dev_ptrs: *mut *mut c_void,
    sizes: *mut usize,
    count: usize,
    flags: c_ulonglong,
    stream: hipStream_t,
) -> hipError_t
@brief Discards a batch of memory ranges asynchronously.

@param [in] dev_ptrs pointers to the memory ranges to discard @param [in] sizes sizes in bytes of the memory ranges to discard @param [in] count number of memory ranges to discard @param [in] flags flags for future use, must be zero now. @param [in] stream stream to enqueue the discard operation

@returns #hipSuccess, #hipErrorInvalidValue, #hipErrorNotSupported

@warning Reading from a discarded range without first writing or prefetching to it will return an indeterminate value. @warning Concurrent reads, writes, or prefetches to discarded ranges result in undefined behavior.

@note All memory ranges must be managed memory allocated via hipMallocManaged or system-allocated memory (if device supports pageable memory access). @note This API is implemented on Linux and requires XNACK to be enabled. @note This API is marked as beta, meaning, while this is feature complete, it is still open to changes and may have outstanding issues.

@see hipMemPrefetchBatchAsync, hipMallocManaged