hipMemPrefetchBatchAsync

Function hipMemPrefetchBatchAsync 

pub unsafe extern "C" fn hipMemPrefetchBatchAsync(
    dev_ptrs: *mut *mut c_void,
    sizes: *mut usize,
    count: usize,
    prefetch_locs: *mut hipMemLocation,
    prefetch_loc_idxs: *mut usize,
    num_prefetch_locs: usize,
    flags: c_ulonglong,
    stream: hipStream_t,
) -> hipError_t
@brief Prefetches a batch of memory ranges to the specified locations using HIP.

@param [in] dev_ptrs pointers to the memory ranges to prefetch @param [in] sizes sizes in bytes of the memory ranges to prefetch @param [in] count number of memory ranges to prefetch @param [in] prefetch_locs locations to prefetch the memory ranges to @param [in] prefetch_loc_idxs indices of the memory ranges to prefetch @param [in] num_prefetch_locs number of locations to prefetch @param [in] flags flags for future use, must be zero now. @param [in] stream stream to enqueue the prefetch operation

@returns #hipSuccess, #hipErrorInvalidValue

@note This API is implemented on Linux and is under development on Microsoft Windows.