pub unsafe extern "C" fn hipMemSetMemPool(
location: *mut hipMemLocation,
type_: hipMemAllocationType,
pool: hipMemPool_t,
) -> hipError_tExpand description
@brief Sets memory pool for memory location and allocation type.
pub unsafe extern "C" fn hipMemSetMemPool(
location: *mut hipMemLocation,
type_: hipMemAllocationType,
pool: hipMemPool_t,
) -> hipError_t@brief Sets memory pool for memory location and allocation type.