pub unsafe extern "C" fn hipMemsetD2D16Async(
dst: hipDeviceptr_t,
dstPitch: usize,
value: c_ushort,
width: usize,
height: usize,
stream: hipStream_t,
) -> hipError_tExpand description
@brief Fills 2D memory range of ‘width’ 16-bit values asynchronously to the specified short value. Height specifies numbers of rows to set and dstPitch speicifies the number of bytes between each row. @param[in] dst Pointer to device memory @param[in] dstPitch Pitch of dst device pointer @param[in] value value to set @param[in] width Width of row @param[in] height Number of rows @param[in] stream Stream Identifier @returns #hipSuccess, #hipErrorInvalidValue