pub unsafe extern "C" fn hipModuleLoadFatBinary(
module: *mut hipModule_t,
fatbin: *const c_void,
) -> hipError_tExpand description
@} / /**
@defgroup Module Module Management @{ @ingroup API This section describes the module management functions of HIP runtime API.
/ /** @brief Loads fatbin object
@param [in] fatbin fatbin to be loaded as a module @param [out] module Module
@returns #hipSuccess, #hipErrorInvalidValue, #hipErrorInvalidContext, #hipErrorFileNotFound, #hipErrorOutOfMemory, #hipErrorSharedObjectInitFailed, #hipErrorNotInitialized