hipOccupancyMaxActiveClusters

Function hipOccupancyMaxActiveClusters 

pub unsafe extern "C" fn hipOccupancyMaxActiveClusters(
    numClusters: *mut c_int,
    f: *const c_void,
    config: *const hipLaunchConfig_t,
) -> hipError_t
@brief determines the amount of active kernel clusters can co-exist at the same time in a device

@param [out] numClusters the amount of clusters @param [in] f kernel function for which occupancy is calculated @param [in] config pointer to the kernel launch configuration structure

@returns #hipSuccess, #hipErrorInvalidDeviceFunction, hipErrorInvalidClusterSize, #hipErrorInvalidValue