#[repr(C)]pub struct hipExtDynDataPrefetchRegion {
pub address: *mut c_void,
pub stride: usize,
pub width: usize,
pub height: usize,
}Expand description
@brief Describes one 2D memory region to prefetch into L2 cache.
@p address must be aligned to the device’s L2 cache line size. @p width is measured in bytes and must be a multiple of the cache line size. @p height is the number of rows to prefetch. @p stride is the byte stride between the start of consecutive rows.
Fields
address: *mut c_void< Base address (must be cache-line aligned)
stride: usize< Stride between row starts in bytes
width: usize< Width of each row in bytes (must be a multiple of cache line size)
height: usize< Number of rows to prefetch