#[repr(C)]pub struct hipLaunchAttributeValue__bindgen_ty_1 {
pub x: c_uint,
pub y: c_uint,
pub z: c_uint,
}Expand description
@brief Specifies the desired cluster dimensions for a kernel launch.
This opaque type is used as the value for the launch attribute ::hipLaunchAttributeClusterDimension. It defines the dimensions of the compute cluster in terms of blocks, where each field must evenly divide the corresponding grid dimension:
- \p x: Number of blocks along the X-axis.
- \p y: Number of blocks along the Y-axis.
- \p z: Number of blocks along the Z-axis.
Fields
x: c_uinty: c_uintz: c_uintTrait Implementations
Sourceimpl Clone for hipLaunchAttributeValue__bindgen_ty_1
impl Clone for hipLaunchAttributeValue__bindgen_ty_1
Sourcefn clone(&self) -> hipLaunchAttributeValue__bindgen_ty_1
fn clone(&self) -> hipLaunchAttributeValue__bindgen_ty_1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for hipLaunchAttributeValue__bindgen_ty_1