pub unsafe extern "C" fn hipMipmappedArrayGetMemoryRequirements(
memoryRequirements: *mut hipArrayMemoryRequirements,
mipmap: hipMipmappedArray_t,
device: hipDevice_t,
) -> hipError_tExpand description
@brief Returns the memory requirements of a HIP mipmapped array.
@param[out] memoryRequirements Pointer to hipArrayMemoryRequirements @param[in] mipmap HIP mipmapped array to get the memory requirements of @param[in] device Device to get the memory requirements for
@returns #hipSuccess, #hipErrorInvalidValue
Returns the memory requirements of a HIP mipmapped array in memoryRequirements.
The returned value in hipArrayMemoryRequirements::size represents the total size of the HIP mipmapped array. The returned value in hipArrayMemoryRequirements::alignment represents the alignment necessary for mapping the HIP mipmapped array.